package Chart::Clicker::Shape;
use Moose;

1;
__END__

=head1 NAME

Chart::Clicker::Shape

=head1 DESCRIPTION

Chart::Clicker::Shape represents a geometric shape.

=head1 SYNOPSIS

=head1 METHODS

=head2 Constructor

=over 4

=item new

Creates a new Chart::Clicker::Shape.

=back

=head2 Class Methods

=over 4

=back

=head1 AUTHOR

Cory 'G' Watson <gphat@cpan.org>

=head1 SEE ALSO

perl(1)

=head1 LICENSE

You can redistribute and/or modify this code under the same terms as Perl
itself.
